==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/admin/menu.php <==
<?php
// $Id: menu.php,v 1.3 2005/09/09 05:40:32 tani Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

$adminmenu[1]['title'] = _MI_XOONIPS_ADMENU1;
$adminmenu[1]['link'] = "admin/config_test.php";
$adminmenu[2]['title'] = _MI_XOONIPS_ADMENU2;
$adminmenu[2]['link'] = "admin/useradmin.php";
$adminmenu[3]['title'] = _MI_XOONIPS_ADMENU3;
$adminmenu[3]['link'] = "admin/config.php";
$adminmenu[4]['title'] = _MI_XOONIPS_ADMENU4;
$adminmenu[4]['link'] = "admin/pickup.php";
$adminmenu[5]['title'] = _MI_XOONIPS_ADMENU5;
$adminmenu[5]['link'] = "admin/oaipmh.php";
?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/admin/menu.php <==
<?php
// $Id: menu.php,v 1.8 2006/08/30 06:43:35 makotonton Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

$adminmenu[1]['title'] = _MI_XOONIPS_ADMENU2;
$adminmenu[1]['link'] = "admin/useradmin.php";
$adminmenu[2]['title'] = _MI_XOONIPS_ADMENU3;
$adminmenu[2]['link'] = "admin/config.php";
$adminmenu[3]['title'] = _MI_XOONIPS_ADMENU4;
$adminmenu[3]['link'] = "admin/pickup.php";
$adminmenu[4]['title'] = _MI_XOONIPS_ADMENU5;
$adminmenu[4]['link'] = "admin/oaipmh.php";
$adminmenu[5]['title'] = _MI_XOONIPS_ADMENU6;
$adminmenu[5]['link'] = "admin/filesearch.php";
$adminmenu[6]['title'] = _MI_XOONIPS_ADMENU7;
$adminmenu[6]['link'] = "admin/posi_order.php";
$adminmenu[7]['title'] = _MI_XOONIPS_ADMENU8;
$adminmenu[7]['link'] = "admin/ranking.php";
$adminmenu[8]['title'] = _MI_XOONIPS_ADMENU9;
$adminmenu[8]['link'] = "admin/ranking_log.php";
$adminmenu[9]['title'] = _MI_XOONIPS_ADMENU10;
$adminmenu[9]['link'] = "admin/itemtype_order.php";
?>
